import requests
import json


def is_human(captcha_response: dict, secret: str):
    """
    Validating recaptcha response from google server
    Returns True captcha test passed for submitted form else returns False.

    Keyword arguments:
    captcha_response -- dict: contains users response to captcha challenge
    secret -- str: Secret key for Google reCAPTCHA
    """
    payload = {'response': captcha_response, 'secret': secret}
    response = requests.post("https://www.google.com/recaptcha/api/siteverify",
                             payload)
    response_text = json.loads(response.text)
    return response_text['success']



import time
import os


def write(string: str, delay: float = 0.06):
    """Print text to the console as if it was being typed.

    Keyword arguments:
    string -- str: Message to be written to the console.
    delay -- float: Delay between each character.
    """
    try:
        for i in str(string):
            print(i, end="", flush=True)
            time.sleep(delay)
        print()
        
        return True

    except Exception as e:
        return False



import smtplib
from email.message import EmailMessage


class Email:
    """Connect to SMTP server and send emails

        Keyword arguments:
        recipient -- str: email address of recipient
        sender -- str: email address of sender
        password -- str: password of sender
        server -- str: SMTP server (default 'smtp.yandex.com')
        port -- int: SMTP port (default 465)

    """

    def __init__(self, recipient: str, sender: str, password: str, server: str = 'smtp.yandex.com', port: int = 465):
        """Connect to SMTP server and set self variables"""
        self.recipient = recipient
        self.sender = sender
        self.server = smtplib.SMTP_SSL(server, port)
        try:
            self.server.login(self.sender, password)
        except Exception as e:
            print(e)

    def send_email(self, subject, message):
        """Send an email

        Keyword arguments:
        subject -- str: Email subject
        message -- str: Email content/message
        """
        email = f'Name: {self.name}\nEmail: {self.email}\nSubject: {self.subject}\nMessage: {message}'
        msg = EmailMessage()
        msg.set_content(email)
        msg['Subject'] = subject
        msg['From'] = self.sender
        msg['To'] = self.recipient
        try:
            self.server.send_message(msg)
            print('Email successfully sent')
            return True
        except Exception as e:
            print(e)
            return False



import os


def clear():
    """Clear the console"""
    # Check if Operating System is Mac and Linux or Windows
    try:
        if os.name == 'posix':
            # If OS is macOS or Linux
            _ = os.system('clear')
        elif os.name == 'nt':
            # Else Operating System is Windows (os.name = nt)
            _ = os.system('cls')
        return True

    except Exception as e:
        print(e)
        return False
